RunnableLambda

Struct RunnableLambda 

pub struct RunnableLambda<I, O>
where I: Send + 'static, O: Send + 'static,
{ /* private fields */ }
Runnable<I, O> backed by a user-supplied async closure.

The closure receives the input and an owned ExecutionContext (cheaply Clone). It must return a future that is Send + 'static — common in practice when the closure body uses owned data and tokio primitives.

Implementations

Source

impl<I, O> RunnableLambda<I, O>
where I: Send + 'static, O: Send + 'static,

pub fn new<F, Fut>(f: F) -> RunnableLambda<I, O>
where F: Fn(I, ExecutionContext) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<O, Error>> + Send + 'static,

Wrap an async closure into a Runnable.

let double = RunnableLambda::new(|x: i32, _ctx| async move { Ok(x * 2) });